==> cms-db_v0.8.1.tar.gz: admin/sudo-gui.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	include('friendlyerror.firewall.inc.php');
	die();
}

function sudo_gui($section) {
	include('locale.inc.php');
	$locale = new LocalizingClass('nopermission');
	$path = (strpos($_SERVER['SCRIPT_NAME'], '/update/index.php') === false) ? './' : '../';
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('pagetitle',false,$locale) ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="<?php echo $path ?>style.css">
		<style type="text/css">
		<!--
		table#sudo, table#sudo td {
			border: none;
		}
		table#sudo {
			background: #eee;
			color: #000;
			border: 1px solid #aaa;
		}
		table#sudo td.top {
			padding-top: 1.5em;
		}
		table#sudo td.right {
			padding-right: 1.5em;
		}
		table#sudo td.bottom {
			padding-bottom: 1.5em;
		}
		table#sudo td.left,
		table#sudo td.leftlabel {
			padding-left: 1.5em
		}
		table#sudo td.label {
			padding-left: .5em;
		}
		-->
		</style>
	</head>
	<body>
		<h1><?php locale('pagetitle',false,$locale) ?></h1>
		<p><?php locale('desc_nopermission',false,$locale) ?></p>
		<p><?php locale('desc_changeuser',false,$locale) ?></p>
		<form action="<?php echo $path ?>sudo.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
			<input type="hidden" name="url" value="<?php echo $_SERVER['REQUEST_URI'] ?>" />
			<table id="sudo">
				<tr>
					<td rowspan="3" class="top left bottom">
						<img src="<?php echo $path ?>key.png" width="64" height="64" alt="" />
					</td>
					<td class="top leftlabel">
						<label for="username"><?php locale('label_username',false,$locale) ?></label>
					</td>
					<td class="top right">
						<select id="username" name="username" size="1">
							<?php
							if ($handle = opendir('../data/users')) {
								while (false !== ($file = readdir($handle))) {
									if(is_file('../data/users/'.$file) && user_has_rights($file, $section)) {
										include('../data/users/'.$file);
										echo '<option value="'.$user.'">'.$user.'</option>';
									}
								}
								closedir($handle);
							}
							?>
						</select>
					</td>
				</tr>
				<tr>
					<td class="leftlabel">
						<label for="password"><?php locale('label_password',false,$locale) ?></label>
					</td>
					<td class="right">
						<input type="password" id="password" name="password" value="" />
					</td>
				</tr>
				<tr>
					<td class="bottom">&nbsp;</td>
					<td class="right bottom">
						<input type="submit" value="<?php locale('button_changeuser',false,$locale) ?>" />
					</td>
				</tr>
			</table>
		</form>
	</body>
</html>
<?php
}
?>

==> cms-db_v0.9.tar.gz: admin/sudo-gui.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	include('friendlyerror.firewall.inc.php');
	die();
}

function sudo_gui($section) {
	include('locale.inc.php');
	$locale = new LocalizingClass('nopermission');
	$path = (strpos($_SERVER['SCRIPT_NAME'], '/update/index.php') === false) ? './' : '../';
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('pagetitle',false,$locale) ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="<?php echo $path ?>style.css">
		<style type="text/css">
		<!--
		table#sudo, table#sudo td {
			border: none;
		}
		table#sudo {
			background: #f4f4f4;
			color: #000;
			border: 1px solid #ccc;
		}
		table#sudo td.top {
			padding-top: 1.5em;
		}
		table#sudo td.right {
			padding-right: 1.5em;
		}
		table#sudo td.bottom {
			padding-bottom: 1.5em;
		}
		table#sudo td.left,
		table#sudo td.leftlabel {
			padding-left: 1.5em
		}
		table#sudo td.label {
			padding-left: .5em;
		}
		-->
		</style>
	</head>
	<body>
		<h1><?php locale('pagetitle',false,$locale) ?></h1>
		<p><?php locale('desc_nopermission',false,$locale) ?></p>
		<p><?php locale('desc_changeuser',false,$locale) ?></p>
		<form action="<?php echo $path ?>sudo.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
			<input type="hidden" name="url" value="<?php echo $_SERVER['REQUEST_URI'] ?>" />
			<table id="sudo">
				<tr>
					<td rowspan="3" class="top left bottom">
						<img src="<?php echo $path ?>key.png" width="64" height="64" alt="" />
					</td>
					<td class="top leftlabel">
						<label for="username"><?php locale('label_username',false,$locale) ?></label>
					</td>
					<td class="top right">
						<select id="username" name="username" size="1">
							<?php
							if ($handle = opendir('../data/users')) {
								while (false !== ($file = readdir($handle))) {
									if(is_file('../data/users/'.$file) && user_has_rights($file, $section)) {
										include('../data/users/'.$file);
										echo '<option value="'.$user.'">'.$user.'</option>';
									}
								}
								closedir($handle);
							}
							?>
						</select>
					</td>
				</tr>
				<tr>
					<td class="leftlabel">
						<label for="password"><?php locale('label_password',false,$locale) ?></label>
					</td>
					<td class="right">
						<input type="password" id="password" name="password" value="" />
					</td>
				</tr>
				<tr>
					<td class="bottom">&nbsp;</td>
					<td class="right bottom">
						<input type="submit" value="<?php locale('button_changeuser',false,$locale) ?>" />
					</td>
				</tr>
			</table>
		</form>
	</body>
</html>
<?php
}
?>
